import { WebClient } from "ticketengine-sdk";
import { Customer, EventPrice, Order, ProductDefinition, ProductPrice } from "./Model";
import { OrderValidator } from "./OrderValidator";
export declare class Cart {
    client: WebClient;
    retryPolicy: number[];
    constructor(options: CartOptions);
    getClient(): WebClient;
    login(username: string, password: string): Promise<void>;
    isTokenExpired(): boolean;
    getEvent(eventId: string): Promise<Event>;
    getEventPrices(eventId: string): Promise<Array<EventPrice>>;
    getProductDefinition(productDefinitionId: string): Promise<ProductDefinition>;
    getProductPrices(productDefinitionId: string): Promise<Array<ProductPrice>>;
    getCustomer(customerId: string): Promise<Customer>;
    getOrder(orderId: string, validator?: OrderValidator, retryPolicy?: Array<number>, forceReload?: boolean): Promise<Order>;
    private fetchOrder;
    createOrder(): Promise<void>;
    cancelOrder(orderId?: string): Promise<void>;
    addItems(items: Array<AddItem>): Promise<void>;
    removeItems(items: Array<RemoveItem>): Promise<void>;
    changeItems(addItems: AddItem[] | undefined, removeItems: Array<RemoveItem>): Promise<void>;
    private mapToCartOperations;
    getItemCount(): Promise<number>;
    addToken(token: string): Promise<void>;
    reserve(email?: string, timeoutOn?: string): Promise<void>;
    checkout(email?: string, payments?: Array<Payment>): Promise<CheckoutResult>;
    private createPayment;
    getOrderId(): string;
    private static setOrder;
    hasOrder(): boolean;
    clearOrder(): void;
    setCustomer(customerId: string): Promise<void>;
    removeCustomer(): Promise<void>;
    private static setCustomerId;
    getCustomerId(): string;
    hasCustomerId(): boolean;
    getSalesChannelId(): string;
    setSalesChannelId(salesChannelId: string): void;
    hasSalesChannelId(): boolean;
    clearSalesChannelId(): void;
    getRegisterId(): string;
    setRegisterId(registerId: string): void;
    hasRegisterId(): boolean;
    clearRegisterId(): void;
    private static isAccessCartItem;
    private static isProductCartItem;
    private sleep;
}
export interface CartOptions {
    salesChannelId: string;
    registerId: string;
    customerId?: string;
    clientId?: string;
    clientSecret?: string;
    scope?: string;
    authUrl?: string;
    adminApiUrl?: string;
    graphApiUrl?: string;
}
export interface AddItem {
}
export interface AddAccessItem extends AddItem {
    eventManagerId: string;
    eventId: string;
    accessDefinitionId: string;
    requestedConditionPath: Array<string>;
    capacityLocationPath?: string;
}
export interface AddProductItem extends AddItem {
    productDefinitionId: string;
    requestedConditionPath: Array<string>;
}
export interface RemoveItem {
    orderLineItemId: string;
}
export interface CheckoutResult {
    paymentResults: Array<PaymentResult>;
}
export interface Payment {
    currencyCode: string;
    amount: number;
    method?: string;
    token?: string;
}
export interface PaymentResult {
    paymentId: string;
    action?: PaymentAction;
}
export interface PaymentAction {
}
export interface RedirectToPaymentPage extends PaymentAction {
    paymentUrl?: string;
}
